@@ -3,54 +3,46 @@ makeExpression <- local({
 
   tmpl_expr_local <- bquote_compile(base::local(.(expr)))
 
-  tmpl_enter <- bquote_compile({
+  tmpl_enter_optenvar <- bquote_compile({
     ## Start time for future evaluation
     ...future.startTime <- base::Sys.time()
     
+    ## Required packages are loaded and attached here
+    .(enter)
+
+    ## Record R options and environment variables
+    ## Note, we do this _after_ loading and attaching packages, in
+    ## case they set options/env vars needed for the session, e.g.
+    ## https://github.com/Rdatatable/data.table/issues/5375
     ...future.oldOptions <- base::as.list(base::.Options)
     ...future.oldEnvVars <- base::Sys.getenv()
-    
-    ## covr: skip=7
-    base::options(
-      ## Prevent .future.R from being source():d when future is attached
-      future.startup.script      = FALSE,
-      
-      ## Assert globals when future is created (or at run time)?
-      future.globals.onMissing   = .(globals.onMissing),
-      
-      ## Pass down other future.* options
-      future.globals.maxSize         = .(getOption("future.globals.maxSize")),
-      future.globals.method          = .(getOption("future.globals.method")),
-      future.globals.onMissing       = .(getOption("future.globals.onMissing")),
-      future.globals.onReference     = .(getOption("future.globals.onReference")),
-      future.globals.resolve         = .(getOption("future.globals.resolve")),
-      future.resolve.recursive       = .(getOption("future.resolve.recursive")),
-      future.rng.onMisuse            = .(getOption("future.rng.onMisuse")),
-      future.rng.onMisuse.keepFuture = .(getOption("future.rng.onMisuse.keepFuture")),
-      future.stdout.windows.reencode = .(getOption("future.stdout.windows.reencode")),
-
-      ## Other options relevant to making futures behave consistently
-      ## across backends
-      width = .(getOption("width"))
-    )
-    .(enter)
   })
 
-  tmpl_exit <- bquote_compile({
-    .(exit)
-    
+  tmpl_exit_optenvar <- bquote_compile({
     ## (a) Reset options
     base::options(...future.oldOptions)
 
+    ## There might be packages that add essential R options when
+    ## loaded or attached, and if their R options are removed, some of
+    ## those packages might break. Because we don't know which these
+    ## packages are, and we cannot detect when a random packages is
+    ## loaded/attached, we cannot reliably workaround R options added
+    ## on package load/attach.  For this reason, I'll relax the
+    ## resetting of R options to only be done to preexisting R options
+    ## for now. These thoughts were triggered by a related data.table
+    ## issue, cf. https://github.com/HenrikBengtsson/future/issues/609
+    ## /HB 2022-04-29
+    
     ## (b) Remove any options added
-    diff <- base::setdiff(base::names(base::.Options), base::names(...future.oldOptions))
-    if (base::length(diff) > 0L) {
-      opts <- base::vector("list", length = base::length(diff))
-      base::names(opts) <- diff
-      base::options(opts)
-    }
+    ## diff <- base::setdiff(base::names(base::.Options),
+    ##                       base::names(...future.oldOptions))
+    ## if (base::length(diff) > 0L) {
+    ##    opts <- base::vector("list", length = base::length(diff))
+    ##    base::names(opts) <- diff
+    ##    base::options(opts)
+    ## }
 
-    ## (c) Reset environment variables
+    ## (d) Reset environment variables
     if (.Platform$OS.type == "windows") {
       ## On MS Windows, you cannot have empty environment variables. When one
       ## is assigned an empty string, MS Windows interpretes that as it should
@@ -80,11 +72,72 @@ makeExpression <- local({
       base::do.call(base::Sys.setenv, args = base::as.list(...future.oldEnvVars))
     }
     
+    ## For the same reason as we don't remove added R options, we don't
+    ## remove added environment variables until we know it's safe.
+    ## /HB 2022-04-30
     ## (d) Remove any environment variables added
-    diff <- base::setdiff(base::names(base::Sys.getenv()), base::names(...future.oldEnvVars))
-    base::Sys.unsetenv(diff)
+    ## diff <- base::setdiff(base::names(base::Sys.getenv()), base::names(...future.oldEnvVars))
+    ## base::Sys.unsetenv(diff)
+    
+    .(exit)
   })
 
+
+  tmpl_enter_future_opts <- bquote_compile({
+    .(enter)
+
+    ## covr: skip=7
+    base::options(
+      ## Prevent .future.R from being source():d when future is attached
+      future.startup.script      = FALSE,
+      
+      ## Assert globals when future is created (or at run time)?
+      future.globals.onMissing   = .(globals.onMissing),
+      
+      ## Pass down other future.* options
+      future.globals.maxSize         = .(getOption("future.globals.maxSize")),
+      future.globals.method          = .(getOption("future.globals.method")),
+      future.globals.onMissing       = .(getOption("future.globals.onMissing")),
+      future.globals.onReference     = .(getOption("future.globals.onReference")),
+      future.globals.resolve         = .(getOption("future.globals.resolve")),
+      future.resolve.recursive       = .(getOption("future.resolve.recursive")),
+      future.rng.onMisuse            = .(getOption("future.rng.onMisuse")),
+      future.rng.onMisuse.keepFuture = .(getOption("future.rng.onMisuse.keepFuture")),
+      future.stdout.windows.reencode = .(getOption("future.stdout.windows.reencode")),
+
+      ## Other options relevant to making futures behave consistently
+      ## across backends
+      width = .(getOption("width"))      
+    )
+
+    ## Record above future options
+    ...future.futureOptionsAdded <- base::setdiff(base::names(base::.Options), base::names(...future.oldOptions))
+  })
+
+
+  tmpl_exit_future_opts <- bquote_compile({
+    ## Remove any "future" options added
+    if (base::length(...future.futureOptionsAdded) > 0L) {
+      opts <- base::vector("list", length = base::length(...future.futureOptionsAdded))
+      base::names(opts) <- ...future.futureOptionsAdded
+      base::options(opts)
+    }
+    
+    .(exit)
+  })
+
+
+  tmpl_enter_workdir <- bquote_compile({
+    .(enter)
+    ...future.workdir <- getwd()
+  })
+
+  tmpl_exit_workdir <- bquote_compile({
+    if (!identical(...future.workdir, getwd())) setwd(...future.workdir)
+    .(exit)
+  })
+
+
   tmpl_expr_evaluate <- bquote_compile({
     ## covr: skip=6
     .(enter)
@@ -265,9 +318,14 @@ makeExpression <- local({
       skip <- skip.local
     }
   
-    ## Set and reset certain future.* options etc.
-    enter <- bquote_apply(tmpl_enter)
-    exit <- bquote_apply(tmpl_exit)
+    ## Set and reset certain properties and states
+    enter <- bquote_apply(tmpl_enter_workdir)
+    enter <- bquote_apply(tmpl_enter_optenvar)
+    enter <- bquote_apply(tmpl_enter_future_opts)
+    
+    exit <- bquote_apply(tmpl_exit_future_opts)
+    exit <- bquote_apply(tmpl_exit_optenvar)
+    exit <- bquote_apply(tmpl_exit_workdir)
   
     if (version == "1.8") {    
       expr <- bquote_apply(tmpl_expr_evaluate)
