@@ -104,21 +104,12 @@ envname <- function(env) {
   if (!is.environment(env)) return(NA_character_)
   name <- environmentName(env)
   if (name == "") {
-    class <- class(env)
-    if (identical(class, "environment")) {
-      ## e.g. new.env()
-      name <- capture.output(print(env))
-    } else {
-      ## It might be that 'env' is on a class that extends 'environment',
-      ## e.g. R.oo::Object() or R6::R6Class().
-      ## IMPORTANT: The unset class must be temporary, because changing
-      ## the class of an environment will
-      name <- local({
-        on.exit(class(env) <- class)
-        class(env) <- NULL
-        capture.output(print(env))
-      })
-    }
+    ## NOTE: I might be that:
+    ## 1. 'env' is of a class that extends 'environment', e.g.
+    ##    R.oo::Object() or R6::R6Class(), or
+    ## 2. another package defines print() for 'environment'
+    ## Because of this, we call print.default() instead of generic print().
+    name <- capture.output(print.default(env))
     if (length(name) > 1L) name <- name[1]
     name <- gsub("(.*: |>)", "", name)
   } else {
